Lists
:::::

.. toctree::
   :caption: Lists
   :maxdepth: 2

   intro-Lists.rst
   ListValues.rst
   ListLength.rst
   AccessingElements.rst
   ListMembership.rst
   ConcatenationandRepetition.rst
   ListSlices.rst
   ListsareMutable.rst
   ListDeletion.rst
   ObjectsandReferences.rst
   Aliasing.rst
   CloningLists.rst
   RepetitionandReferences.rst
   ListMethods.rst
   TheReturnofLSystems.rst
   AppendversusConcatenate.rst
   Listsandforloops.rst
   TheAccumulatorPatternwithLists.rst
   UsingListsasParameters.rst
   PureFunctions.rst
   WhichisBetter.rst
   FunctionsthatProduceLists.rst
   ListComprehensions.rst
   NestedLists.rst
   StringsandLists.rst
   listTypeConversionFunction.rst
   TuplesandMutability.rst
   TupleAssignment.rst
   TuplesasReturnValues.rst
   Glossary.rst
   Exercises.rst
